@@ -1,5 +1,7 @@
 #!/bin/bash
 
+echo "===== Extracting Test library C++ source code files ====="
+
 # ---------------------- TestLib.h ----------------------
 # Example taken from distributed source ./sdk/libraries/cepcoreschema/testdata/TestLib.h
 cat <<EOF > TestLib.h
@@ -28,3 +30,5 @@ void TestLib::test() {
     std::cout << "Test output" << std::endl;
 }
 EOF
+
+echo "[OK]"
\ No newline at end of file
